#include "fabgl.h"
#include "vtanimations.h"
#include <WiFi.h>

// VGA 显示
fabgl::VGA16Controller DisplayController;
fabgl::Terminal        Terminal;

const char *ssid = "intel_001665"; //网络名称
const char *password = "12345678"; //网络密码

// 使用阿里的 NTP 获得当前时间
const char* ntpServer = "ntp.aliyun.com";
// 时区修正，我们在东八区
const long  gmtOffset_sec = 8 * 60 * 60;
// 夏令时修正
const int   daylightOffset_sec = 0;

void setup() {
  struct tm timeinfo;
  Serial.begin(115200);

  // Connect to Wi-Fi
  Serial.print("Connecting to ");
  Serial.println(ssid);
  WiFi.begin(ssid, password);
  while (WiFi.status() != WL_CONNECTED) {
    delay(500);
    Serial.print(".");
  }
  Serial.println("");
  Serial.println("WiFi connected.");
  delay(2000);
  Serial.println("Connect to NTP server");
  // 从 NTP Server 获得时间
  configTime(gmtOffset_sec, daylightOffset_sec, ntpServer);
  // 如果没有成功获取，那么重启 ESP32
  if (!getLocalTime(&timeinfo)) {
    Serial.println("Failed to obtain time, retry");
    delay(5000);
    ESP.restart();
  }
  Serial.println("Got time");
  // 取得时间后即可断开 WIFI
  WiFi.disconnect(true);
  WiFi.mode(WIFI_OFF);


  DisplayController.begin();
  // 设定分辨率
  DisplayController.setResolution(VGA_640x480_60Hz);

  // 创建 Terminal
  Terminal.begin(&DisplayController);
  Terminal.enableCursor(true);

  // 背景为黑，文字绿色
  Terminal.write("\e[40;92m");
  // 请屏幕
  Terminal.write("\e[2J");

  Terminal.write("\e[20h");
  //Terminal.write("\e[92m");
  // 关闭光标
  Terminal.enableCursor(false);

}

void loop() {

  int i = 0;
  while (i < sizeof(vt_animation) - 4) {
    // 如果当前要发送回归第一行的命令，就输出当前时间
    if (vt_animation[i] == 0x1B && vt_animation[i + 1] == 0x5B && vt_animation[i + 2] == 0x48) {
      struct tm timeinfo;
      // 取得当前时间
      getLocalTime(&timeinfo);

      char buf[60];
      // 年月日
      sprintf(buf, "\e[10;56H%d/%02d/%02d", timeinfo.tm_year + 1900, timeinfo.tm_mon + 1, timeinfo.tm_mday);
      Serial.println(buf);
      Terminal.write(buf);
      //小时分钟秒
      sprintf(buf, "\e[14;56H%02d:%02d:%02d", timeinfo.tm_hour, timeinfo.tm_min, timeinfo.tm_sec);
      Serial.println(buf);
      Terminal.write(buf);

      // 输出回归第一行的命令
      Terminal.write(vt_animation[i]);
      Terminal.write(vt_animation[i + 1]);
      Terminal.write(vt_animation[i + 2]);
      // 跳过这个命令
      i = i + 3;
    }
    Terminal.write(vt_animation[i]);
    i++;
  }

}

